# frozen_string_literal: true

require "rails/generators"

module UserDocs
  # Installs the required files
  class InstallGenerator < Rails::Generators::Base
    source_root File.expand_path("templates", __dir__)

    def create
      check_for_version

      template "index", ".docs/index.html"
      template "_layouts/default", ".docs/_layouts/default.html"
      template "_includes/index", ".docs/_includes/index.html"
      empty_directory ".docs/_data/versions"
      empty_directory ".docs/versions"
    end

    private

    def check_for_version
      host_app = Rails.application.class
      return if defined?(host_app.module_parent::VERSION)

      # :nocov:
      abort "ERROR: version needs to defined as "\
            "#{host_app.module_parent}::VERSION."
      # :nocov:
    end
  end
end
